@@ -64,7 +64,7 @@ sub _new {
 	}
 
 	# 状態の初期化。
-	$this->_reset;
+	$this->reset;
 
 	$this;
 }
@@ -123,6 +123,7 @@ sub flush {
 		$output = $data;
 		
 	} else {
+		# 一度以上 print を通るので, _flush_header は呼び出し済み.
 		my $data = $this->{buffer};
 		$this->{buffer} = '';
 
@@ -139,8 +140,6 @@ sub flush {
 		}
 	}
 
-	$this->_reset;
-
 	$output;
 }
 
@@ -397,9 +396,9 @@ sub _relink {
 	$url . $fragment;
 }
 
-sub _reset {
+sub reset {
 	my $this = shift;
-	$this->SUPER::_reset;
+	$this->SUPER::reset;
 
 	# Contentが1バイトでも出力されたかどうか
 	$this->{content_printed} = undef;
@@ -535,6 +534,10 @@ L<Tripletail::Filter>参照
 
 L<Tripletail::Filter>参照
 
+=item reset
+
+L<Tripletail::Filter>参照
+
 =back
 
 
