@@ -101,14 +101,12 @@ sub flush {
 		$output = $this->{buffer};
 	}
 
-	$this->_reset;
-	
 	$output;
 }
 
-sub _reset {
+sub reset {
 	my $this = shift;
-	$this->SUPER::_reset;
+	$this->SUPER::reset;
 	
 	$this->{buffer} = '';
 	
@@ -146,6 +144,10 @@ L<Tripletail::Filter>参照
 
 L<Tripletail::Filter>参照
 
+=item reset
+
+L<Tripletail::Filter>参照
+
 =back
 
 =head2 フィルタパラメータ
