@@ -71,14 +71,13 @@ sub flush {
 	if(!$this->{content_printed}) {
 		die __PACKAGE__."#flush: no contents have been printed during this request. (リクエスト処理で何もprintされていません)\n";
 	}
-	$this->_reset;
 
 	'';
 }
 
-sub _reset {
+sub reset {
 	my $this = shift;
-	$this->SUPER::_reset;
+	$this->SUPER::reset;
 
 	$this->{content_printed} = undef;
 
@@ -154,6 +153,10 @@ L<Tripletail::Filter>参照
 
 L<Tripletail::Filter>参照
 
+=item reset
+
+L<Tripletail::Filter>参照
+
 =back
 
 
