@@ -427,6 +427,41 @@ $checkmaskは空白で区切って複数個指定する事が可能。
 
 指定の正規表現に該当するかをチェックする。指定値がない場合には、エラー。
 
+=item SingleValue
+
+値がただ1つ存在することをチェックする拒否フィルタ。
+
+1つのみ存在すれば、次のフィルタに処理を渡す。
+
+2つ以上存在する、若しくは1つも存在しない場合には、
+その時点で処理を中断し、エラーを返す。
+
+=item MultiValues
+
+  MultiValues($min)
+  MultiValues($min,$max)
+
+値が指定した C<$min> 個以上, C<$max> 個以下の範囲で
+存在することをチェックする拒否フィルタ。
+
+個数が範囲内であれば、
+次のフィルタに処理を渡す。
+
+個数が範囲外だった場合には、
+その時点で処理を中断し、エラーを返す。
+
+C<$max> を省略した場合、上限個数の確認は行わない。
+
+=item NoValues
+
+値が存在しないことを受け付ける受理フィルタ。
+
+値を全く持っていなければ、
+その時点で処理を中断し、成功を返す。
+
+何らかの値が(空欄であったとしても)存在した場合には、
+次のフィルタに処理を渡す。
+
 =back
 
 =head3 組み込みcorrectフィルタ
